Crate lib_cpi_macros

Crate lib_cpi_macros 

Macros

register_actions
Macro to register action functions with the CpiExtension trait

Attribute Macros

action
Macro to annotate extension action functions with metadata
generate_metadata
Macro to generate the metadata function for an action This should be called after all param annotations
param
Macro to define parameter metadata for actions